@@ -2,7 +2,7 @@
 Renders the command line on the console.
 (Redraws parts of the input line that were changed.)
 """
-from asyncio import FIRST_COMPLETED, Future, sleep, wait
+from asyncio import FIRST_COMPLETED, Future, ensure_future, sleep, wait
 from collections import deque
 from enum import Enum
 from typing import TYPE_CHECKING, Any, Callable, Deque, Dict, Hashable, Optional, Tuple
@@ -566,11 +566,11 @@ class Renderer:
                 response_f.cancel()
             self._waiting_for_cpr_futures = deque()
 
-        coroutines = [
-            wait_for_responses(),
-            wait_for_timeout(),
-        ]
-        _, pending = await wait(coroutines, return_when=FIRST_COMPLETED)
+        tasks = {
+            ensure_future(wait_for_responses()),
+            ensure_future(wait_for_timeout()),
+        }
+        _, pending = await wait(tasks, return_when=FIRST_COMPLETED)
         for task in pending:
             task.cancel()
 
@@ -631,7 +631,7 @@ class Renderer:
 
         height = min(height, size.rows)
 
-        # When te size changes, don't consider the previous screen.
+        # When the size changes, don't consider the previous screen.
         if self._last_size != size:
             self._last_screen = None
 
@@ -757,6 +757,7 @@ def print_formatted_text(
     # Reset first.
     output.reset_attributes()
     output.enable_autowrap()
+    last_attrs: Optional[Attrs] = None
 
     # Print all (style_str, text) tuples.
     attrs_for_style_string = _StyleStringToAttrsCache(
@@ -766,10 +767,13 @@ def print_formatted_text(
     for style_str, text, *_ in fragments:
         attrs = attrs_for_style_string[style_str]
 
-        if attrs:
-            output.set_attributes(attrs, color_depth)
-        else:
-            output.reset_attributes()
+        # Set style attributes if something changed.
+        if attrs != last_attrs:
+            if attrs:
+                output.set_attributes(attrs, color_depth)
+            else:
+                output.reset_attributes()
+        last_attrs = attrs
 
         # Eliminate carriage returns
         text = text.replace("\r", "")
